import { aws_route53 as route53, aws_s3 as s3 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Properties for AssetCdn L3 construct
 */
export interface AssetCdnProps {
    /**
     * Domain name of the asset content delivery network (e.g. example.com)
     */
    domainName: string;
    /**
     * Hostname of the asset content delivery network (e.g. cdn)
     */
    hostName: string;
}
/**
 * The AssetCdn construct is responsible for setting up an S3 bucket for asset storage
 * and a CloudFront distribution to serve the assets securely with HTTPS. It also
 * configures a Route 53 DNS record to point to the CloudFront distribution.
 */
export declare class AssetCdn extends Construct {
    /**
     * The Route 53 hosted zone for the asset domain.
     */
    readonly zone: route53.IHostedZone;
    /**
     * The S3 bucket used to store the assets.
     */
    readonly assetBucket: s3.Bucket;
    /**
     * The domain name used for accessing the assets.
     */
    readonly assetDomainName: string;
    /**
     * Creates an instance of AssetCdn.
     *
     * @param scope - The scope in which this construct is defined.
     * @param id - The scoped construct ID.
     * @param props - The properties of the AssetCdn construct.
     */
    constructor(scope: Construct, id: string, props: AssetCdnProps);
}
